"""
MODULE:     menudata.py

CLASSES:
    * Data

PURPOSE:    Complex list for main menu entries for GRASS wxPython GUI.

AUTHORS:    The GRASS Development Team
            Michael Barton (Arizona State University)
            Yann Chemin
            Martin Landa <landa.martin gmail.com>
            
COPYRIGHT:  (C) 2007-2008 by the GRASS Development Team
            This program is free software under the GNU General Public
            License (>=v2). Read the file COPYING that comes with GRASS
            for details.

"""

import os

class Data:
    '''Data object that returns menu descriptions to be used in wxgui.py.
    Probably could be changed to XML or *.dtd file.'''
    def GetMenu(self):
        return [(
          ("File", (
              ("Workspace", (
                 ("New", "Create new workspace file (erase current workspace settings first)", "self.OnWorkspaceNew", ""),
                 ("Open", "Open existing workspace file", "self.OnWorkspaceOpen", ""),
                 ("Load", "Load map layers into layer tree", "self.OnWorkspaceLoad", ""),
                 ("Save", "Save current workspace to file", "self.OnWorkspaceSave", ""),
                 ("Save as", "Save current workspace as", "self.OnWorkspaceSaveAs", ""),
                 ("Close", "Close selected workspace file", "self.OnWorkspaceClose", ""),
                 )),
              ("","","", ""),
              ("Import raster map", (
                 ("Multiple import formats using GDAL", "Import multiple formats using GDAL", "self.OnMenuCmd", "r.in.gdal"),
                 ("","","", ""),
                 ("Aggregate ASCII xyz import", "Import aggregate ASCII xyz data", "self.OnMenuCmd", "r.in.xyz"),
                 ("ASCII grid import", "Import ASCII GRID (includes GRASS ASCII)", "self.OnMenuCmd", "r.in.ascii"),
                 ("ASCII polygons and lines import", "Import Polygons and lines from ASCII file", "self.OnMenuCmd", "r.in.poly"),
                 ("","","", ""),
                 ("Binary import", "Import binary file (includes GTOPO30 format)", "self.OnMenuCmd", "r.in.bin"),
                 ("ESRI ASCII grid import", "Import ESRI Arc/Info ASCII grid", "self.OnMenuCmd", "r.in.arc"),
                 ("GRIDATB.FOR import", "Import GRIDATB.FOR map file (TOPMODEL)", "self.OnMenuCmd", "r.in.gridatb"),
                 ("MAT-File (v.4) import", "Import MAT-File (v.4) array (Matlab or Octave)", "self.OnMenuCmd", "r.in.mat"),
                 ("SPOT NDVI import", "Import SPOT vegetation NDVI data sets", "self.OnMenuCmd", "r.in.spotvgt"),
                 ("SRTM HGT import", "Import SRTM hgt files", "self.OnMenuCmd", "r.in.srtm"),
                 ("Terra ASTER HDF import", "Import Terra ASTER HDF files", "self.OnMenuCmd", "r.in.aster"),
                 ("","","", ""),
                 ("WMS import", "Import Web Mapping Server", "self.OnMenuCmd", "r.in.wms"),
                 )),
              ("Import vector map", (
                 ("Multiple import formats using OGR", "Import multiple formats using OGR", "self.OnMenuCmd", "v.in.ogr"),
                 ("","","", ""),
                 ("ASCII points/GRASS ASCII vector import", "Import ASCII points file or GRASS ASCII vector file", "self.OnMenuCmd", "v.in.ascii"),
                 ("Old GRASS vector import", "Import old GRASS vector format", "self.OnMenuCmd", "v.convert"),
                 ("","","", ""),
                 ("DXF import", "Import DXF file", "self.OnMenuCmd", "v.in.dxf"),
                 ("ESRI e00 import", "Import ESRI e00 file", "self.OnMenuCmd", "v.in.e00"),
                 ("Garmin GPS import", "Import Garmin GPS Waypoints/Routes/Tracks", "self.OnMenuCmd", "v.in.garmin"),
                 ("GPSBabel GPS import", "Import GPS Waypoints/Routes/Tracks using GPSBabel", "self.OnMenuCmd", "v.in.gpsbabel"),
                 ("GEOnet import", "Import GEOnet Name server country files (US-NGA GNS)", "self.OnMenuCmd", "v.in.gns"),
                 ("Matlab and MapGen import", "Import Matlab and MapGen files", "self.OnMenuCmd", "v.in.mapgen"),
                 )),
              ("Import grid 3D volume", (
                 ("ASCII 3D import", "Import ASCII 3D file", "self.OnMenuCmd", "r3.in.ascii"),
                 ("Vis5D import", "Import Vis5D file", "self.OnMenuCmd", "r3.in.v5d"),
                 )),
              ("Import database table", (
                 ("Multiple import formats using OGR", "Import multiple formats using OGR", "self.OnMenuCmd", "db.in.ogr"),
                 )),
              ("","","", ""),
              ("Export raster map", (
                 ("Multiple export formats using GDAL", "Export multiple formats using GDAL", "self.OnMenuCmd", "r.out.gdal"),
                 ("","","", ""),
                 ("ASCII grid export", "Export ASCII grid (for GRASS, Surfer, Modflow, etc)", "self.OnMenuCmd", "r.out.ascii"),
                 ("ASCII x,y,z export", "Export ASCII x,y,z values of cell centers", "self.OnMenuCmd", "r.out.xyz"),
                 ("","","", ""),
                 ("ESRI ASCII grid export", "Export ESRI Arc/Info ASCII grid", "self.OnMenuCmd", "r.out.arc"),
                 ("GRIDATB.FOR export", "Export GRIDATB.FOR map file (TOPMODEL)", "self.OnMenuCmd", "r.out.gridatb"),
                 ("MAT-File (v.4) export", "Export MAT-File (v.4) array (Matlab or Octave)", "self.OnMenuCmd", "r.out.mat"),
                 ("","","", ""),
                 ("Binary export", "Export binary file", "self.OnMenuCmd", "r.out.bin"),
                 ("","","", ""),
                 ("MPEG-1 export", "Export MPEG-1 animations", "self.OnMenuCmd", "r.out.mpeg"),
                 ("PNG export", "Export PNG image (not georeferenced)", "self.OnMenuCmd", "r.out.png"),
                 ("PPM export", "Export PPM image (24bit)", "self.OnMenuCmd", "r.out.ppm"),
                 ("PPM from RGB export", "Export PPM image from red, green, blue raster maps", "self.OnMenuCmd", "r.out.ppm3"),
                 ("POV-Ray export", "Export POVray height-field", "self.OnMenuCmd", "r.out.pov"),
                 ("TIFF export", "Export TIFF image (8/24bit)", "self.OnMenuCmd", "r.out.tiff"),
                 ("VRML export", "Export VRML file", "self.OnMenuCmd", "r.out.vrml"),
                 ("VTK export", "Export VTK ASCII file", "self.OnMenuCmd", "r.out.vtk"),
                 )),
              ("Export vector map", (
                 ("Multiple export formats using OGR", "Export multiple formats using OGR", "self.OnMenuCmd", "v.out.ogr"),
                 ("","","", ""),
                 ("ASCII points/GRASS ASCII vector export", "Import ASCII points file or GRASS ASCII vector file", "self.OnMenuCmd", "v.out.ascii"),
                 ("DXF export", "Export DXF file", "self.OnMenuCmd", "v.out.dxf"),
                 ("POV-Ray export", "Export POV-Ray format file", "self.OnMenuCmd", "v.out.pov"),
                 ("SVG export", "Export SVG file", "self.OnMenuCmd", "v.out.svg"),
                 ("VTK export", "Export VTK ASCII file", "self.OnMenuCmd", "v.out.vtk"),
                 )),
              ("Export grid 3D volume", (
                 ("ASCII 3D export", "Export ASCII 3D file", "self.OnMenuCmd", "r3.out.ascii"),
                 ("Vis5D export", "Export Vis5D file", "self.OnMenuCmd", "r3.out.v5d"),
                 ("VTK export", "Export VTK ASCII file", "self.OnMenuCmd", "r3.out.vtk"),
                 )),
              ("","","", ""),
              ("Manage maps and volumes", (
                ("Copy", "Copy maps within mapsets or between mapsets", "self.OnMenuCmd", "g.copy"),
                ("","","", ""),
                ("List", "List maps by type", "self.OnMenuCmd", "list"),
                ("List filtered", "List maps filtered by expressions and wildcards", "self.OnMenuCmd", "g.mlist"),
                ("","","", ""),
                ("Rename", "Rename maps", "self.OnMenuCmd", "g.rename"),
                ("","","", ""),
                ("Delete", "Delete maps", "self.OnMenuCmd", "g.remove"),
                ("Delete filtered", "Delete maps using expressions and wildcards", "self.OnMenuCmd", "g.mremove"),
                )),
              ("Map type conversions", (
                ("Raster to vector", "Convert raster to vector map", "self.OnMenuCmd", "r.to.vect"),
                ("Raster series to volume", "Convert raster map series to volume", "self.OnMenuCmd", "r.to.rast3"),
                ("Raster 2.5D to volume", "Convert raster 2.5D map to volume", "self.OnMenuCmd", "r.to.rast3elev"),
                ("","","", ""),
                ("Vector to raster", "Convert vector to raster map", "self.OnMenuCmd", "v.to.rast"),
                ("Vector to volume", "Convert vector 3D points to volume voxels", "self.OnMenuCmd", "v.to.rast3"),
                ("Sites to vector", "Convert sites (GRASS 5) to vector map", "self.OnMenuCmd", "v.in.sites"),
                ("","","", ""),
                ("Volume to raster series", "Convert raster to vector map", "self.OnMenuCmd", "r3.to.rast"),
                )),
              ("","","", ""),
              ("Georectify", "Georectify raster and vector maps", "self.OnGeorectify", ""),
              ("","","", ""),
              ("NViz (requires TclTk)", "N-Dimensional visualization of maps and volumes", "self.OnMenuCmd", "nviz"),
              ("","","", ""),
              ("Bearing/distance to coordinates", "Convert between bearing/distance and coordinates", "self.OnMenuCmd", "m.cogo"),
              ("","","", ""),
              ("Postscript plot", "Create cartographic PostScript plot", "self.OnMenuCmd", "ps.map"),
              ("","","", ""),
              ("E&xit", "Exit from wxgui.py", "self.OnCloseWindow", ""),
              )),
          ("Config", (
              ("Region", (
                ("Display region", "Display region settings", "self.RunMenuCmd", "g.region -p"),
                ("Set region", "Change region settings", "self.OnMenuCmd", "g.region"),
              )),
              ("GRASS working environment", (
                ("Mapset access", "Set/unset access to other mapsets in current location", "self.OnMapsets", ""),
                ("Change working environment", "Change current working session to new mapset, location, or data directory", "self.OnMenuCmd", "g.mapset"),
                ("User access", "Change access by other users to current mapset", "self.OnMenuCmd", "g.access"),
                ("Show settings", "Show current GRASS environment settings", "self.RunMenuCmd", "g.gisenv"),
                ("Change settings", "Change GRASS environment settings", "self.OnMenuCmd", "g.gisenv"),
                ("Version", "Show current GRASS version", "self.RunMenuCmd", "g.version -c"),
              )),
              ("Manage projections", (
                ("Manage projections", "Show projection information and create projection files", "self.OnMenuCmd", "g.proj"),
                ("Projection for current location", "Create/edit projection information for current location", "self.OnXTerm", "g.setproj"),
                ("","","", ""),
                ("Convert coordinates", "Convert coordinates from one projection to another", "self.OnMenuCmd", "m.proj"),
              )),
              ("Preferences", "User preferences (display font, etc.)", "self.OnPreferences", ""),
              )),
          ("Raster", (
              ("Develop map", (
                ("Digitize raster (requires XTerm)", "Digitize new raster map", "self.OnXTerm", "r.digit"),
                ("","","", ""),
                ("Compress/decompress", "Compress/decompress raster file", "self.OnMenuCmd", "r.compress"),
                ("","","", ""),
                ("Boundaries", "Manage boundary definition", "self.OnMenuCmd", "r.region"),
                ("Manage NULL values", "Manage NULL values", "self.OnMenuCmd", "r.null"),
                ("Quantization", "Quantization for floating-point maps", "self.OnMenuCmd", "r.quant"),
                ("Timestamp", "Manage timestamp for files", "self.OnMenuCmd", "r.timestamp"),
                ("","","", ""),
                ("Resample using aggregate statistics", "Resample (change resolution) using aggregate statistics", "self.OnMenuCmd", "r.resamp.stats"),
                ("Resample using multiple methods", "Resample (change resolution) using nearest neighbor, bilinear, or bicubic interpolation", "self.OnMenuCmd", "r.resamp.interp"),
                ("Resample using nearest neighbor", "Resample (change resolution) using nearest neighbor interpolation", "self.OnMenuCmd", "r.resample"),
                ("Resample using spline tension", "Resample (change resolution) using regularized spline tension", "self.OnMenuCmd", "r.resamp.rst"),
                ("","","", ""),
                ("Support file maintenance", "Support file creation and maintenance", "self.OnMenuCmd", "r.support"),
                ("Update map statistics", "Update map statistics", "self.OnMenuCmd", "r.support.stats"),
                ("","","", ""),
                ("Reproject raster", "Reproject raster from other location", "self.OnMenuCmd", "r.proj"),
                ("Tiling", "Generate tiling for other projection", "self.OnMenuCmd", "r.tileset"),
                )),
              ("Manage map colors", (
                ("Color tables", "Set colors to predefined color tables", "self.OnMenuCmd", "r.colors"),
                ("Color rules", "Set colors interactively by entering color rules", "self.RulesCmd", "r.colors"),
                ("","","", ""),
                ("Blend 2 color maps", "Blend 2 color maps to produce 3 RGB files", "self.OnMenuCmd", "r.blend"),
                ("Create RGB", "Create color image from RGB files", "self.OnMenuCmd", "r.composite"),
                ("RGB to HIS", "Create 3 RGB (red, green, blue) maps from 3 HIS (hue, intensity, saturation) maps", "self.OnMenuCmd", "r.his"),
                )),
              ("Query by coordinates", "Query by coordinates", "self.OnMenuCmd", "r.what"),
              ("","","", ""),
              ("Buffer rasters", "Create raster buffers around raster objects", "self.OnMenuCmd", "r.buffer"),
              ("Closest points", "r.distance", "self.OnMenuCmd", "r.distance"),
              ("MASK", "Develop raster mask", "self.OnMenuCmd", "r.mask"),
              ("Map calculator", "Map calculator for map algebra", "self.OnMenuCmd", "scripts/mapcalc_gparser.sh"),
              ("Neighborhood analysis", (
                ("Moving window", "Moving window analysis of raster cells", "self.OnMenuCmd", "r.neighbors"),
                ("Neighborhood points", "Analyze vector points in neighborhood of raster cells", "self.OnMenuCmd", "v.neighbors"),
                )),
              ("Overlay maps", (
                ("Cross product", "Cross product", "self.OnMenuCmd", "r.cross"),
                ("Map series", "Function of map series (time series)", "self.OnMenuCmd", "r.series"),
                ("Patch raster maps", "Patch maps", "self.OnMenuCmd", "r.patch"),
                ("","","", ""),
                ("Statistical overlay", "Statistical calculations for cover map over base map", "self.OnMenuCmd", "r.statistics"),
                )),
              ("Solar radiance and shadows", (
                ("Solar irradiance and irradiation", "Solar irradiance and daily irradiation", "self.OnMenuCmd", "r.sun"),
                ("Shadows map", "Shadows map for sun position or date/time", "self.OnMenuCmd", "r.sunmask"),
                )),
              ("Terrain analysis", (
                ("Cumulative movement costs", "Calculate cumulative movement costs between locales", "self.OnMenuCmd", "r.walk"),
                ("Cost surface", "cost surface", "self.OnMenuCmd", "r.cost"),
                ("Least cost route or flow", "Least cost route or flow", "self.OnMenuCmd", "r.drain"),
                ("","","", ""),
                ("Shaded relief", "Shaded relief map", "self.OnMenuCmd", "r.shaded.relief"),
                ("","","", ""),
                ("Slope and aspect", "Slope and aspect", "self.OnMenuCmd", "r.slope.aspect"),
                ("Terrain parameters", "Terrain parameters", "self.OnMenuCmd", "r.param.scale"),
                ("Textural features", "Textural features", "self.OnMenuCmd", "r.texture"),
                ("","","", ""),
                ("Visibility", "Visibility and line of sight", "self.OnMenuCmd", "r.los"),
                )),
              ("Transform features", (
                ("Clump", "Clump small areas (statistics calculated by r.volume)", "self.OnMenuCmd", "r.clump"),
                ("Grow", "Grow areas", "self.OnMenuCmd", "r.grow"),
                ("Thin", "Thin linear features", "self.OnMenuCmd", "r.thin"),
                )),
              ("","","", ""),
              ("Hydrologic modeling", (
                ("Carve stream channels", "Carve stream channels into elevation map using vector streams map", "self.OnMenuCmd", "r.carve"),
                ("Fill lake", "Fill lake from seed point to specified level", "self.OnMenuCmd", "r.lake"),
                ("","","", ""),
                ("Depressionless map and flowlines", "Depressionless elevation map and flowline map", "self.OnMenuCmd", "r.fill.dir"),
                ("Flow accumulation", "Flow accumulation for massive grids", "self.OnMenuCmd", "r.terraflow"),
                ("Flow lines", "Generate flow lines for raster map", "self.OnMenuCmd", "r.flow"),
                ("","","", ""),
                ("SIMWE Overland flow modeling", "SIMWE overland flow modeling", "self.OnMenuCmd", "r.sim.water"),
                ("SIMWE Sediment flux modeling", "SIMWE sediment erosion, transport, deposition modeling", "self.OnMenuCmd", "r.sim.sediment"),
                ("","","", ""),
                ("Topographic index map", "Topographic index map", "self.OnMenuCmd", "r.topidx"),
                ("TOPMODEL simulation", "TOPMODEL simulation", "self.OnMenuCmd", "r.topmodel"),
                ("","","", ""),
                ("Watershed subbasins", "Watershed subbasins", "self.OnMenuCmd", "r.basins.fill"),
                ("Watershed analysis", "Watershed analysis", "self.OnMenuCmd", "r.watershed"),
                ("Watershed basin creation", "Watershed basin creation", "self.OnMenuCmd", "r.water.outlet"),
                )),
              ("Landscape structure modeling", (
                ("Set up (requires XTerm)", "Set up sampling and analysis framework", "self.OnXTerm", "r.le.setup"),
                ("","","", ""),
                ("Analyze landscape", "Analyze landscape characteristics", "self.OnMenuCmd", "r.le.pixel"),
                ("Analyze patches", "Analyze landscape patch characteristics", "self.OnMenuCmd", "r.le.patch"),
                ("Output", "Output landscape patch information", "self.OnMenuCmd", "r.le.trace"),
                )),
              ("Landscape patch analysis", (
                ("Set up sampling and analysis framework", "Configure and create patch map for analysis", "self.OnMenuCmd", "r.li.setup"),
                ("","","", ""),
                ("Edge density", "Calculate edge density index using a 4 neighbour algorithm", "self.OnMenuCmd", "r.li.edgedensity"),
                ("Contrast weighted edge density", "Calculate contrast weighted edge density index", "self.OnMenuCmd", "r.li.cwed"),
                ("","","", ""),
                ("Patch area mean", "Calculate mean patch size index using a 4 neighbour algorithm", "self.OnMenuCmd", "r.li.mps"),
                ("Patch area range", "Calculate range of patch area size", "self.OnMenuCmd", "r.li.padrange"),
                ("Patch area Std Dev", "Calculate standard deviation of patch area", "self.OnMenuCmd", "r.li.padsd"),
                ("Patch area Coeff Var", "Calculate coefficient of variation of patch area", "self.OnMenuCmd", "r.li.padcv"),
                ("Patch density", "Calculate patch density index using a 4 neighbour algorithm", "self.OnMenuCmd", "r.li.patchdensity"),
                ("Patch number", "Calculate patch number index using a 4 neighbour algorithm", "self.OnMenuCmd", "r.li.patchnum"),
                ("","","", ""),
                ("Dominance's diversity", "Calculate Dominance's diversity index", "self.OnMenuCmd", "r.li.dominance"),
                ("Shannon's diversity", "Calculate Shannon's diversity index", "self.OnMenuCmd", "r.li.shannon"),
                ("Simpson's diversity", "Calculate Simpson's diversity index", "self.OnMenuCmd", "r.li.simpson"),
                ("","","", ""),
                ("Richness", "Calculate richness index", "self.OnMenuCmd", "r.li.richness"),
                ("Shape index", "Calculate shape index", "self.OnMenuCmd", "r.li.shape"),
                )),
              ("Wildfire modeling", (
                ("Rate of spread", "Generate rate of spread (ROS) maps", "self.OnMenuCmd", "r.ros"),
                ("Least-cost spread paths", "Generate least-cost spread paths", "self.OnMenuCmd", "r.spreadpath"),
                ("Anisotropic spread simulation", "Simulate anisotropic spread phenomena", "self.OnMenuCmd", "r.spread"),
                )),
              ("","","", ""),
              ("Change category values and labels", (
                ("Interactively edit category values", "Edit category values of individual cells for displayed raster map", "self.OnMenuCmd", "d.rast.edit"),
                ("","","", ""),
                ("Reclassify by size", "Reclassify categories for areas of specified sizes", "self.OnMenuCmd", "r.reclass.area"),
                ("Reclassify interactively", "Reclassify categories interactively by entering reclass rules", "self.RulesCmd", "r.reclass"),
                ("Reclassify using rules file", "Reclassify categories by inputting reclass rules from a text file", "self.OnMenuCmd", "r.reclass"),
                ("","","", ""),
                ("Recode interactively", "Recode categories interactively by entering recode rules (create new map)", "self.RulesCmd", "r.recode"),
                ("Recode using rules file", "Recode categories by inputting recode rules from a text file (create new map)", "self.OnMenuCmd", "r.recode.file"),
                ("","","", ""),
                ("Rescale", "Rescale categories (create new map)", "self.OnMenuCmd", "r.rescale"),
                ("Rescale with histogram", "Rescale categories with equalized histogram (create new map)", "self.OnMenuCmd", "r.rescale.eq"),
                )),
              ("","","", ""),
              ("Concentric circles", "Generate concentric circles around points", "self.OnMenuCmd", "r.circle"),
              ("Generate random cells", (
                ("Random cells", "Generate random cells", "self.OnMenuCmd", "r.random.cells"),
                ("Random cells and vector points ", "Generate random cells and vector points from raster map", "self.OnMenuCmd", "r.random"),
                )),
              ("Generate surfaces", (
                ("Fractal surface", "Generate fractal surface", "self.OnMenuCmd", "r.surf.fractal"),
                ("","","", ""),
                ("Gaussian kernel density surface", "Generate density surface using moving Gaussian kernel", "self.OnMenuCmd", "v.kernel"),
                ("Gaussian deviates surface", "Generate gaussian deviates surface", "self.OnMenuCmd", "r.surf.gauss"),
                ("","","", ""),
                ("Plane", "Generate plane", "self.OnMenuCmd", "r.plane"),
                ("","","", ""),
                ("Random deviates surface", "Generate random deviates surface", "self.OnMenuCmd", "r.surf.random"),
                ("Random surface with spatial dependence", "Generate random surface with spatial dependence", "self.OnMenuCmd", "r.random.surface"),
                )),
              ("Generate contour lines", "Generate vector contour lines", "self.OnMenuCmd", "r.contour"),
              ("Interpolate surfaces", (
                ("Bilinear from raster points", "Bilinear interpolation from raster points", "self.OnMenuCmd", "r.bilinear"),
                ("Bilinear and bicubic from vector points", "Bicubic and bilinear interpolation with Tykhonov regularization from vector points", "self.OnMenuCmd", "v.surf.bspline"),
                ("","","", ""),
                ("IDW from raster points", "Inverse distance weighted interpolation from raster points", "self.OnMenuCmd", "r.surf.idw"),
                ("IDW from vector points", "Inverse distance weighted interpolation from vector points", "self.OnMenuCmd", "v.surf.idw"),
                ("","","", ""),
                ("Raster contours", "Interpolation from raster contour", "self.OnMenuCmd", "r.surf.contour"),
                ("Regularized spline tension ", "Regularized spline tension interpolation from vector points or contours", "self.OnMenuCmd", "v.surf.rst"),
                ("","","", ""),
                ("Fill NULL cells", "Fill NULL cells by interpolation using regularized spline tension", "self.OnMenuCmd", "r.fillnulls"),
                )),
              ("","","", ""),
              ("Report and statistics", (
                ("Basic raster information", "Report basic file information", "self.OnMenuCmd", "r.info"),
                ("Report category information", "Report category labels and values", "self.OnMenuCmd", "r.cats"),
                ("","","", ""),
                ("General statistics", "General statistics", "self.OnMenuCmd", "r.stats"),
                ("Range of category values", "Range of all category values", "self.OnMenuCmd", "r.describe"),
                ("Sum cell category values", "Sum all cell category values", "self.OnMenuCmd", "r.sum"),
                ("Sum area by map and category", "Sum area by map and category", "self.OnMenuCmd", "r.report"),
                ("Statistics for clumped cells", "Summary statistics for clumped cells (work with r.clump)", "self.OnMenuCmd", "r.volume"),
                ("Total corrected area", "Total surface area corrected for topography", "self.OnMenuCmd", "r.surf.area"),
                ("Univariate raster statistics", "Calculate univariate statistics for raster categories", "self.OnMenuCmd", "r.univar"),
                ("","","", ""),
                ("Sample transects", "Sample values along transects", "self.OnMenuCmd", "r.profile"),
                ("Sample transects (bearing/distance)", "Sample values along transects (use azimuth, distance)", "self.OnMenuCmd", "r.transect"),
                ("","","", ""),
                ("Covariance/correlation", "Covariance/correlation", "self.OnMenuCmd", "r.covar"),
                ("Linear regression", "Linear regression between 2 maps", "self.OnMenuCmd", "r.regression.line"),
                ("Mutual category occurrences", "Mutual category occurrences (coincidence)", "self.OnMenuCmd", "r.coin"),
                )),
              )),
          ("Vector", (
              ("Develop vector map", (
                ("Create empty vector map", "Create new empty vector map", "self.OnMenuCmd", "v.edit tool=create"),
                ("Digitize vector map", "Digitize/edit vector map", "self.OnMenuCmd", "v.digit"),
                ("","","", ""),
                ("Create/rebuild topology", "Create or rebuild topology of vector objects", "self.OnMenuCmd", "v.build"),
                ("Clean vector map", "Clean vector objects", "self.OnMenuCmd", "v.clean"),
                ("","","", ""),
                ("Convert object types", "Convert vector objects from one feature type to another", "self.OnMenuCmd", "v.type.sh"),
                ("","","", ""),
                ("Add centroids", "Add centroids to closed boundaries to create areas", "self.OnMenuCmd", "v.centroids"),
                ("","","", ""),
                ("Build polylines", "Build polylines from adjacent segments", "self.OnMenuCmd", "v.build.polylines"),
                ("Split polylines", "Split polylines into points and segments", "self.OnMenuCmd", "v.segment"),
                ("Parallel lines", "Create lines parallel to existing lines", "self.OnMenuCmd", "v.parallel"),
                ("","","", ""),
                ("Dissolve boundaries", "Dissolve common boundaries of areas", "self.OnMenuCmd", "v.dissolve"),
                ("","","", ""),
                ("Create 3D vector map over raster", "Create 3D objects by sampling raster with 2D vector", "self.OnMenuCmd", "v.drape"),
                ("Extrude 3D vector map", "Extrude 3D objects from 2D vector", "self.OnMenuCmd", "v.extrude"),
                ("","","", ""),
                ("Link to OGR", "Create new vector as link to external OGR layer", "self.OnMenuCmd", "v.external"),
                ("","","", ""),
                ("Create labels", "Create text label file for vector features", "self.OnMenuCmd", "v.label"),
                ("","","", ""),
                ("Reposition vector map", "Reposition (shift, rotate, skew) vector file in coordinate space", "self.OnMenuCmd", "v.transform"),
                ("Reproject vector map", "Reproject vector from other location", "self.OnMenuCmd", "v.proj"),
                )),
              ("","","", ""),
              ("Query with attributes", "Query vector objects by attribute values", "self.OnMenuCmd", "v.extract"),
              ("Query with coordinate(s)", "Query vector objects by coordinate(s)", "self.OnMenuCmd", "v.what"),
              ("Query with another vector map", "Query objects using objects from a second map", "self.OnMenuCmd", "v.select"),
              ("","","", ""),
              ("Buffer vectors", "Create vector buffers around vector objects", "self.OnMenuCmd", "v.buffer"),
              ("Lidar analysis", (
                ("Detect edges", "Detect object edges in Lidar data", "self.OnMenuCmd", "v.lidar.edgedetection"),
                ("Detect interiors", "Detect interiors of objects in Lidar data", "self.OnMenuCmd", "v.lidar.growing"),
                ("Correct and reclassify objects", "Correct and reclassify objects detected in Lidar data", "self.OnMenuCmd", "v.lidar.correction"),
                )),
              ("Linear referencing", (
                ("Create LRS", "Create linear reference system", "self.OnMenuCmd", "v.lrs.create"),
                ("Create stationing", "Create stationing from input lines, and linear reference system", "self.OnMenuCmd", "v.lrs.label"),
                ("Create points/segments", "Create points/segments from input lines, linear reference system and positions read from stdin", "self.OnMenuCmd", "v.lrs.segment"),
                ("Find line id and offset", "Find line id and real km+offset for given points in vector map using linear reference system", "self.OnMenuCmd", "v.lrs.where"),
                )),
              ("Nearest features", "Locate nearest feature to points or centroids", "self.OnMenuCmd", "v.distance"),
              ("Network analysis", (
                ("Allocate subnets", "Allocate subnets for nearest centers", "self.OnMenuCmd", "v.net.alloc"),
                ("Network maintenance", "Network maintenance", "self.OnMenuCmd", "v.net"),
                ("Shortest route", "Calculate shortest route along network between 2 nodes", "self.OnMenuCmd", "v.net.path"),
                ("Display shortest route (requires XTerm)", " Display shortest route along network between 2 nodes (visualization only)", "self.OnXTerm", "d.path"),
                ("Split net", "Split net into bands between cost isolines", "self.OnMenuCmd", "v.net.iso"),
                ("Steiner tree", "Create Steiner tree for network and given terminals", "self.OnMenuCmd", "v.net.steiner"),
                ("Traveling salesman analysis", "Calculate shortest route connecting given set of nodes (Traveling salesman analysis)", "self.OnMenuCmd", "v.net.salesman"),
                )),
              ("Overlay vector maps", (
                ("Overlay vector maps", "Boolean overlay of 2 vector maps", "self.OnMenuCmd", "v.overlay"),
                ("Patch vector maps", "Patch/combine multiple maps (Boolean OR)", "self.OnMenuCmd", "v.patch"),
                )),
              ("","","", ""),
              ("Change attributes", (
                ("Manage or report categories", "Attach/delete, or report categories", "self.OnMenuCmd", "v.category"),
                ("Reclassify objects interactively", "Reclassify vector objects interactively by entering SQL rules", "self.RulesCmd", "v.reclass"),
                ("Reclassify objects using rules file", "Reclassify vector objects by inputting SQL rules from a text file", "self.OnMenuCmd", "v.reclass"),
                )),
              ("","","", ""),
              ("Generate area for current region", "Generate area object for extent of current region", "self.OnMenuCmd", "v.in.region"),
              ("Generate areas from points", (
                  ("Convex hull", "Generate convex hull for point set", "self.OnMenuCmd", "v.hull"),
                  ("Delaunay triangles", "Generate Delaunay triangles for point set", "self.OnMenuCmd", "v.delaunay"),
                  ("Voronoi diagram/Thiessen polygons", "Generate Voronoi diagram/Thiessen polygons for point set", "self.OnMenuCmd", "v.voronoi"),
                  )),
              ("Generate grid", "Generate rectangular vector grid", "self.OnMenuCmd", "v.mkgrid"),
              ("Generate points", (
                  ("Generate from database", "Generate points from database with x/y coordinates", "self.OnMenuCmd", "v.in.db"),
                  ("Generate points along lines", "Generate points along vector lines/boundaries", "self.OnMenuCmd", "v.to.points"),
                  ("Generate random points", "Generate random points", "self.OnMenuCmd", "v.random"),
                  ("Perturb points", "Random perturbations of point locations", "self.OnMenuCmd", "v.perturb"),
                  )),
              ("","","", ""),
              ("Remove outliers in point sets", "Remove outliers from vector point set", "self.OnMenuCmd", "v.outlier"),
              ("Test/training point sets", "Partition points into test/training sets for k-fold cross validation", "self.OnMenuCmd", "v.kcv"),
              ("","","", ""),
              ("Update area attributes from raster", "Update area attribute data from univariate statistics on raster map", "self.OnMenuCmd", "v.rast.stats"),
              ("Update point attributes from areas", "Update point attribute data from vector area map", "self.OnMenuCmd", "v.what.vect"),
              ("Update point attributes from raster", (
                  ("Sample raster maps at point locations", "Sample raster maps at point locations", "self.OnMenuCmd", "v.what.rast"),
                  ("Sample raster neighborhood around points", "Sample raster neighborhood around points", "self.OnMenuCmd", "v.sample"),
                  )),
              ("","","", ""),
              ("Reports and statistics", (
                ("Basic vector information", "Basic vector information", "self.OnMenuCmd", "v.info"),
                ("","","", ""),
                ("Report topology by category", "Report areas for vector attribute categories", "self.OnMenuCmd", "v.report"),
                ("Upload or report topology", "Update database fields or create reports from vector topology", "self.OnMenuCmd", "v.to.db"),
                ("","","", ""),
                ("Univariate attribute statistics", "Calculate univariate statistics for vector attributes", "self.OnMenuCmd", "v.univar"),
                ("","","", ""),
                ("Quadrat indices", "Indices of point counts in quadrats", "self.OnMenuCmd", "v.qcount"),
                ("Test normality", "Test normality of point distribution", "self.OnMenuCmd", "v.normal"),
                )),
              )),
          ("Imagery", (
              ("Develop images and groups", (
                ("Create/edit group", "Create/edit imagery group", "self.OnMenuCmd", "i.group"),
                ("Target group", "Target imagery group", "self.OnMenuCmd", "i.target"),
                ("","","", ""),
                ("Mosaic images", "Mosaic up to 4 adjacent images", "self.OnMenuCmd", "i.image.mosaic"),
                )),
              ("Manage image colors", (
                ("Color balance for RGB", "Color balance and enhance color tables of multiband imagery for rgb display", "self.OnMenuCmd", "i.landsat.rgb"),
                ("HIS to RGB", "Transform HIS (Hue/Intensity/Saturation) color image to RGB (Red/Green/Blue)", "self.OnMenuCmd", "i.his.rgb"),
                ("RGB to HIS", "Transform RGB (Red/Green/Blue) color image to HIS (Hue/Intensity/Saturation)", "self.OnMenuCmd", "i.rgb.his"),
                )),
              ("Rectify and georeference image group", (
                ("Set GCP's from raster map (requires Xterm)", "Set ground control points (GCP's) from raster map or keyboard entry", "self.OnXTerm", "i.points"),
                ("Set GCP's from vector map (requires Xterm)", "Set ground control points (GCP's) from vector map or keyboard entry", "self.OnXTerm", "i.vpoints"),
                ("Georectification (rubber sheet)", "Affine and Polynomial rectification (rubber sheet)", "self.OnMenuCmd", "i.rectify"),
                ("Ortho photo rectification (requies Xterm)", "Ortho Photo rectification", "self.OnXTerm", "i.ortho.photo"),
                )),
              ("","","", ""),
              ("Brovey sharpening", "Brovey transformation and pan sharpening", "self.OnMenuCmd", "i.fusion.brovey"),
              ("Classify image", (
                ("Clustering input for unsupervised classification", "Clustering input for unsupervised classification", "self.OnMenuCmd", "i.cluster"),
                ("","","", ""),
                ("Maximum likelihood classification (MLC)", "Maximum likelihood Classification", "self.OnMenuCmd", "i.maxlik"),
                ("Sequential maximum a posteriori classification (SMAP)", "Sequential maximum a posteriori classification (SMAP)", "self.OnMenuCmd", "i.smap"),
                ("","","", ""),
                ("Interactive input for supervised classification (requires Xterm)", "Interactive input for supervised classification", "self.OnXTerm", "i.class"),
                ("Input for supervised MLC", "Non-interactive input for supervised classification (MLC)", "self.OnMenuCmd", "i.gensig"),
                ("Input for supervised SMAP", "Non-interactive input for supervised classification (SMAP)", "self.OnMenuCmd", "i.gensigset"),
                )),
              ("Filter image", (
                ("Edge detection", "Zero edge crossing detection", "self.OnMenuCmd", "i.zc"),
                ("Matrix/convolving filter", "User defined matrix/convolving filter", "self.OnMenuCmd", "r.mfilter"),
                )),
              ("Histogram image", "Histogram image", "self.DispHistogram", ""),
              ("Spectral response", "Spectral response", "self.OnMenuCmd", "i.spectral"),
              ("Tasseled cap vegetation index", "Tasseled cap vegetation index", "self.OnMenuCmd", "i.tasscap"),
              ("Transform image", (
                ("Canonical correlation", "Canonical correlation (discriminant analysis)", "self.OnMenuCmd", "i.cca"),
                ("Principal components", "Principal components analysis", "self.OnMenuCmd", "i.pca"),
                ("Fast Fourier", "Fast Fourier Transform", "self.OnMenuCmd", "i.fft"),
                ("Inverse Fast Fourier", "Inverse Fast Fourier Transform", "self.OnMenuCmd", "i.ifft"),
                )),
              ("","","", ""),
              ("Report and statistics", (
                ("Bit pattern comparison ", "Bit pattern comparison for ID of low quality pixels", "self.OnMenuCmd", "r.bitpattern"),
                ("Kappa analysis", "Kappa classification accuracy assessment", "self.OnMenuCmd", "r.kappa"),
                ("OIF for LandSat TM", "Optimum index factor for LandSat TM", "self.OnMenuCmd", "i.oif"),
                )),
              )),
          ("Volumes", (
              ("Develop grid3D volumes", (
                ("Manage 3d NULL values", "Manage NULL values for grid3D volume", "self.OnMenuCmd", "r3.null"),
                ("Manage timestamp", "Manage timestamp for grid3D volume", "self.OnMenuCmd", "r3.timestamp"),
                )),
              ("","","", ""),
              ("3D MASK", "Create 3D mask for grid3D operations", "self.OnMenuCmd", "r3.mask"),
              ("3D map calculator", "Map calculator for volumetric map algebra", "self.OnMenuCmd", "r3.mapcalculator"),
              ("Cross section", "Create 2D raster cross section from grid3d volume", "self.OnMenuCmd", "r3.cross.rast"),
              ("Interpolate volume from points", "Interpolate volume from vector points using splines", "self.OnMenuCmd", "v.vol.rst"),
              ("","","", ""),
              ("Report and Statistics", (
                ("Basic volume information", "Report basic information about grid3D volume", "self.OnMenuCmd", "r3.info"),
                )),
              )),
          ("Database", (
              ("Database information", (
                ("Describe table", "Describe table structure and attributes", "self.OnMenuCmd", "db.describe"),
                ("List columns", "List columns for selected table", "self.OnMenuCmd", "db.columns"),
                ("List drivers", "List available database drivers", "self.OnMenuCmd", "db.drivers"),
                ("List tables", "List tables in database", "self.OnMenuCmd", "db.tables"),
                )),
              ("","","", ""),
              ("Manage databases", (
                ("Connect", "Connect to database", "self.OnMenuCmd", "db.connect"),
                ("Login", "Login to database", "self.OnMenuCmd", "db.login"),
                ("","","", ""),
                ("Copy table", "Copy attribute table", "self.OnMenuCmd", "db.copy"),
                ("New table", "Create and connect new attribute table to vector map", "self.OnMenuCmd", "v.db.addtable"),
                ("Remove table", "Remove existing attribute table for vector map", "self.OnMenuCmd", "db.login"),
                ("","","", ""),
                ("Add columns", "Add columns to table", "self.OnMenuCmd", "v.db.addcol"),
                ("Change values", "Change values in a column", "self.OnMenuCmd", "v.db.update"),
                ("Rename column", "Rename a column", "self.OnMenuCmd", "v.db.renamecol"),
                ("","","", ""),
                ("Test", "Test database", "self.OnMenuCmd", "db.test"),
                )),
              ("Query", (
                ("Query any table", "Query data in any table", "self.OnMenuCmd", "db.select"),
                ("Query vector attribute table", "Query vector attribute data", "self.OnMenuCmd", "v.db.select"),
                ("SQL statement", "Execute SQL statement", "self.OnMenuCmd", "db.execute"),
                )),
              ("","","", ""),
              ("Vector<->database connections", (
                ("Reconnect vector to database", "Reconnect vector map to attribute database", "self.OnMenuCmd", "v.db.reconnect.all"),
                ("Set vector - database connection", "Set database connection for vector attributes", "self.OnMenuCmd", "v.db.connect"),
                )),
              )),
          ("Help", (
              ("GRASS GIS help", "GRASS GIS Reference Manual", "self.RunMenuCmd", "g.manual -i"),
              ("GRASS GIS GUI help", "GUI-related Reference Manual", "self.RunMenuCmd", "g.manual wxGUI"),
              ("About GRASS GIS", "About GRASS GIS", "self.OnAboutGRASS", ""),
              )))]
